@@ -28,7 +28,8 @@ from .utils.csp_connect import connect_to_csp
 from .sql.misc import sql_enquote_id
 from .utils.df_utils import CloseAfterIteration, load_dataframe_from_sql, LoadStrategy, coerce_to_dataframe, \
     convertible_to_dataframe
-from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem, adapt_fsspec_storage_options
+from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem, adapt_fsspec_storage_options, \
+    is_breakout_path
 from .utils.format_sniffer import find_url_extension, detect_format, FORMAT_ALIASES_WRITE_OPTIONS
 from .utils.nosql import connect_to_nosql
 #from .utils.packages import install_packages
@@ -272,7 +273,13 @@ class DSLibrary(object):
             fs = self.get_filesystem_connection(filesystem, for_write="r" not in mode, **open_args)
             # TODO some of 'open_args' might be appropriate to send to open() below rather than get_filesystem_connection(), above
             return fs.open(uri, mode=mode)
-        # 'path' has the URI or path of what we need to open
+        # when a 'root' folder is applied we apply it here
+        #  - any we can't allow paths that 'break out' to the parent folders
+        if "root" in kwargs:
+            if is_breakout_path(uri):
+                raise DSLibraryException(f"invalid path: {uri}")
+            uri = os.path.join(kwargs.get("root"), uri)
+        # 'uri' has the URI or path of what we need to open
         # 'mode' has the open mode
         # 'open_args' has additional arguments to pass
         return self._opener(uri, mode, **open_args)
