@@ -71,7 +71,7 @@ class ModelRunner(object):
         if ":" in uri:
             return uri
         if uri.startswith("~/"):
-            # specifically point to files within the sandbox
+            # specifically point to files within the 'model-root'
             return "./" + uri[1:]
         if uri.startswith("/"):
             # already absolute
@@ -82,6 +82,19 @@ class ModelRunner(object):
     def set_input(self, name: str, uri: str="", data=None, **kwargs):
         """
         Specify where data will come from for a particular named input.
+
+        Reference a single table:
+          set_input("the_data", uri="local.csv", format_options={"delimiter": "\t"})
+          set_input("the_data", uri="s3://my_bucket/remote.csv", access_key=..., secret_key=...)
+
+        Reference a set of files:
+          set_input("the_files", uri="/some/local/folder/")
+          set_input("the_files", uri="s3://my_bucket", access_key=..., secret_key=..., root="limit_to_this_subfolder")
+
+        Reference an SQL engine:
+          set_input("my_sql_db", uri="mysql://host/database", username=..., password=...)
+          set_input("my_sql_db", uri="/folder/with/each_table_in_this_folder_is_a_file/")
+
         :param name:    Name of input.
         :param uri:     A path to a local file, or the URI of remote data.  Or, a URI specifying a sql or nosql data
                         source.
