@@ -18,7 +18,11 @@ def connect_to_database(uri: str, library: str=None, for_write: bool=False, **kw
     libraries = []
     if library:
         libraries.append(library)
-    uri_parts = uri.split(":")
+    if ":" not in uri:
+        # we can point to a folder and each file is treated as a table
+        from dslibrary.utils.folder_db import connect_to_folder_as_database
+        return connect_to_folder_as_database(uri, for_write=for_write, **kwargs)
+    uri_parts = uri.split(":", maxsplit=1)
     if uri_parts[0] == "jdbc":
         uri_parts = uri_parts[1:]
     if uri_parts[0] in ("postgres", "postgresql"):
