@@ -175,6 +175,26 @@ def adapt_fsspec_storage_options(opts: dict) -> dict:
     return opts
 
 
+def is_breakout_path(path: str) -> bool:
+    """
+    Determine whether a path attempts to 'escape' to its parent or siblings.
+    """
+    level = 0
+    for elem in path.split("/"):
+        if elem in ("", "."):
+            # empty
+            continue
+        if elem == "..":
+            # up
+            level -= 1
+            if level < 0:
+                return True
+        else:
+            # down
+            level += 1
+    return False
+
+
 KNOWN_FSSPEC_STORAGE_OPTIONS = {
     "access_key": "key", "secret_key": "secret", "service_account": "service_account",
     "account_name": "account_name", "account_key": "account_key"
