@@ -466,17 +466,27 @@ class TestFront(unittest.TestCase):
         # not a log function but close enough
         self.assertRaises(DSLibraryException, lambda: inst.get_metrics("x"))
 
-    def test_mlflow_start_end(self):
+    def test_mlflow_1_start_end(self):
         inst = DSLibrary()
         inst._mlflow_all = True
         log = []
-        with mock.patch("mlflow.mlflow.start_run", lambda: log.append("start")):
+        class RunInfo(object):
+            run_id = "RUN_ID"
+        class Run(object):
+            info = RunInfo()
+        with mock.patch("mlflow.mlflow.start_run", lambda: log.append("start") or Run()):
             with mock.patch("mlflow.mlflow.end_run", lambda: log.append("end")):
-                with mock.patch("mlflow.active_run", lambda: log.append("active_run")):
-                    # TODO mock this: mlflow.active_run().info.run_id
-                    with inst.start_run():
-                        pass
-        self.assertEqual(log, ['start', 'active_run', 'end'])
+                with inst.start_run():
+                    self.assertEqual("RUN_ID", inst._run_id)
+                self.assertEqual(None, inst._run_id)
+        self.assertEqual(log, ['start', 'end'])
+
+    def test_mlflow_0_start_end(self):
+        inst = DSLibrary()
+        inst._mlflow_all = False
+        with inst.start_run():
+            assert len(inst._run_id) > 12
+        self.assertEqual(None, inst._run_id)
 
     def test_yaml(self):
         data = [
