@@ -1,3 +1,4 @@
+import io
 import unittest
 import os
 import json
@@ -305,5 +306,65 @@ class TestRunMethod(unittest.TestCase):
         with mock.patch("dslibrary.front.connect_to_database", connect):
             runner.run_method(my_model)
 
+    def test_named_folder_file_source(self):
+        """
+        A local folder that can be substituted for an s3 bucket.
+        """
+        def open(path, mode=None):
+            self.assertEqual("/folder/file", str(path))
+            return io.BytesIO(b"abc")
+        with mock.patch("pathlib.Path.open", open):
+            def my_model(dsl):
+                r = dsl.read_resource("file", filesystem="the_files")
+                self.assertEqual(b"abc", r)
+            runner = ModelRunner()
+            runner.set_input("the_files", uri="/folder")
+            runner.run_method(my_model)
+
+    def test_s3_folder_file_supplied(self):
+        """
+        An s3 bucket, filename comes from read_resource().
+        """
+        def open(inst, path, **kwargs):
+            self.assertEqual("file", path)
+            return io.BytesIO(b"abc")
+        with mock.patch("dslibrary.engine_intf.S3Connection.open", open):
+            def my_model(dsl):
+                r = dsl.read_resource("file", filesystem="the_files")
+                self.assertEqual(b"abc", r)
+            runner = ModelRunner()
+            runner.set_input("the_files", uri="s3://bucket", access_key="A", secret_key="S")
+            runner.run_method(my_model)
+
+    def test_s3_folder_file_part_of_spec(self):
+        """
+        The named source is a specific file in an s3 bucket.
+        """
+        def open(inst, path, mode, **kwargs):
+            self.assertEqual("s3://bucket/file", path)
+            return io.BytesIO(b"abc")
+        with mock.patch("dslibrary.transport.to_local.DSLibraryLocal._opener", open):
+            def my_model(dsl):
+                r = dsl.read_resource("the_file")
+                self.assertEqual(b"abc", r)
+            runner = ModelRunner()
+            runner.set_input("the_file", uri="s3://bucket/file", access_key="A", secret_key="S")
+            runner.run_method(my_model)
+
+    def test_sql_select__db_as_folder(self):
+        """
+        A local folder can substitute for a remote database.
+        """
+        def open(inst, path, mode, **kwargs):
+            self.assertEqual("/folder/t1", path)
+            return io.BytesIO(b"x\n1\n2\n30")
+        with mock.patch("dslibrary.transport.to_local.DSLibraryLocal._opener", open):
+            def my_model(dsl):
+                df = dsl.sql_select("select x from t1", engine="the_files")
+                self.assertEqual([1, 2, 30], list(df.x))
+            runner = ModelRunner()
+            runner.set_input("the_files", uri="/folder")
+            runner.run_method(my_model)
+
     def tearDown(self) -> None:
         reset_env("test_run_method")
