@@ -5,7 +5,7 @@ import io
 import mock
 
 from dslibrary.utils.file_utils import FileOpener, connect_to_filesystem, write_stream_with_read_on_close, \
-    adapt_fsspec_storage_options
+    adapt_fsspec_storage_options, is_breakout_path
 
 
 class TestFileUtils(unittest.TestCase):
@@ -57,3 +57,14 @@ class TestFileUtils(unittest.TestCase):
         self.assertEqual(adapt_fsspec_storage_options({"access_key": "K"}), {'storage_options': {'key': 'K'}})
         self.assertEqual(adapt_fsspec_storage_options({"key": "K"}), {'storage_options': {'key': 'K'}})
         self.assertEqual(adapt_fsspec_storage_options({"storage_options": {"x": 1}, "access_key": "K", "z": 2}), {'storage_options': {'key': 'K', 'x': 1}, 'z': 2})
+
+    def test_is_breakout_path(self):
+        self.assertEqual(True,  is_breakout_path("../x"))
+        self.assertEqual(False, is_breakout_path("x/.."))
+        self.assertEqual(True,  is_breakout_path("x/../.."))
+        self.assertEqual(False, is_breakout_path("x/y/../.."))
+        self.assertEqual(False, is_breakout_path("x/y/../../z"))
+        self.assertEqual(True,  is_breakout_path("x/y/../../z/../.."))
+        self.assertEqual(False, is_breakout_path("./"))
+        self.assertEqual(True,  is_breakout_path("./.."))
+
